# ppscore

## Predictive Power Score _(currently working on this)_
A score that helps identifying linear and non-linear relations between features/attributes.

Because I was unable to find the option to explicitly mention categorical and numerical features in one of the libraries offering ppscore, which was leading to regression in case of categorical attribute. PyCustom.pps will rectify this issue (At Least that is the vision currently).

To install this library use:
```
pip install pps-python
```

To use Predictive Power Score, import the following:  <br>
```
from pps.ppscore import pps
```
